.. Places parent toc into the sidebar

:parenttoc: True

.. include:: includes/big_toc_css.rst

.. _supervised-learning:

Supervised learning
-------------------

.. toctree::
    :maxdepth: 2

    modules/linear_model
    modules/lda_qda.rst
    modules/kernel_ridge.rst
    modules/svm
    modules/sgd
    modules/neighbors
    modules/gaussian_process
    modules/cross_decomposition.rst
    modules/naive_bayes
    modules/tree
    modules/ensemble
    modules/multiclass
    modules/feature_selection.rst
    modules/semi_supervised.rst
    modules/isotonic.rst
    modules/calibration.rst
    modules/neural_networks_supervised
